@@ -59,6 +59,7 @@ class UI(LoggingMixin):
         if 'login' not in context or context['login'] is None:  # type: ignore
             post_redirect = self._authenticator._session_validator.pop_post_auth_redirect(request)
             context['login'] = '<br>'.join([provider.get_login_button(post_redirect) for provider in self._authenticator._providers])  # type: ignore
+        self.logger.debug(f'Context {context}')
         return self.login_templates.TemplateResponse(self.login_template_path.name, context)  # type: ignore
 
     def _get_user(self, request: Request, **kwargs):
@@ -143,10 +144,11 @@ class UI(LoggingMixin):
         redirect = urls.with_query_params(request.url.path, **request.query_params)
         self.logger.debug(f'Request {request.url}')
         self.logger.info(f'Forcing authentication with redirect = {redirect}')
-        if len(self._authenticator._providers) == 1:
-            redirect_url = urls.with_query_params(self._authenticator._providers[0].login_url, redirect=redirect, force=True)
+        providers = [u for u in self._authenticator._providers if u.authenticator]
+        if len(providers) == 1:
+            redirect_url = urls.with_query_params(providers[0].login_url, redirect=redirect, force=True)
         else:
-            redirect_url = urls.with_query_params(self.config.routing.landing_path, redirect=redirect)
+            redirect_url = urls.with_query_params(self.config.routing.login_path, redirect=redirect, force=True)
         if ajax:
             self.logger.debug(f'AJAX is true - handling {redirect_url}')
             url = urls.parse_url(redirect_url)
@@ -161,10 +163,11 @@ class UI(LoggingMixin):
     def __get_access_token(self, user, scopes=None):
         access_token = None
         for provider in self._authenticator._providers:
-            try:
-                access_token = provider.authenticator.get_access_token(user, scopes)
-            except ValueError:
-                pass
+            if provider.authenticator:
+                try:
+                    access_token = provider.authenticator.get_access_token(user, scopes)
+                except ValueError:
+                    pass
             if access_token is not None:
                 break
         return access_token
